@@ -35,6 +35,7 @@
 #define IFTRACE if (0)
 #endif
 
+
 namespace wreport {
 namespace bulletin {
 
@@ -152,6 +153,7 @@ void Visitor::b_variable(Varcode code)
     }
 }
 
+
 void Visitor::c_modifier(Varcode code)
 {
     TRACE("C DATA %01d%02d%03d\n", WR_VAR_F(code), WR_VAR_X(code), WR_VAR_Y(code));
@@ -185,7 +187,7 @@ void Visitor::c_associated_field(Varcode code, Varcode sig_code, unsigned nbits)
 
         // Encode B31021
         const Var& var = do_semantic_var(info);
-        c04_meaning = var.enqi();
+        c04_meaning = var.enq(63);
         ++data_pos;
     }
     c04_bits = WR_VAR_Y(code);
